@@ -1,6 +1,6 @@
 package SPVM::File::Spec;
 
-our $VERSION = "0.085";
+our $VERSION = "0.086";
 
 1;
 
@@ -16,7 +16,7 @@ File::Spec class in L<SPVM> has methods to perform operations on file names port
 
   use File::Spec;
   
-  my $file = File::Spec->catfile(["foo", "bar"], "a.txt"]);
+  my $file = File::Spec->catfile(["foo", "bar", "a.txt"]);
 
 =head1 Class Methods
 
@@ -26,11 +26,11 @@ File::Spec class in L<SPVM> has methods to perform operations on file names port
 
 =head2 catdir
 
-  static method catdir : string ($directories : string[]);
+  static method catdir : string ($parts : string[]);
 
 =head2 catfile
 
-  static method catfile : string ($directories : string[], $filename : string);
+  static method catfile : string ($parts : string[]);
 
 =head2 curdir
 
@@ -54,7 +54,7 @@ File::Spec class in L<SPVM> has methods to perform operations on file names port
 
 =head2 no_upwards
 
-  static method no_upwards : string[] ($directories : string[]);
+  static method no_upwards : string[] ($parts : string[]);
 
 =head2 file_name_is_absolute
 
@@ -70,7 +70,7 @@ File::Spec class in L<SPVM> has methods to perform operations on file names port
 
 =head2 join
 
-  static method join : string ($directories : string[], $filename : string);
+  static method join : string ($parts : string[]);
 
 =head2 splitpath
 
@@ -82,7 +82,7 @@ File::Spec class in L<SPVM> has methods to perform operations on file names port
 
 =head2 catpath
 
-  static method catpath : string ($volume : string, $directory : string, $file : string);
+  static method catpath : string ($volume : string, $dir : string, $file : string);
 
 =head2 abs2rel
 
